==> union-update-2.8.46.tgz: package/index.js <==
'use strict';

/**
 * Gives same value.
 * @param v a value
 * @returns v
 */
function id(v) {
    return v;
}

/**
 * Compares two values.
 * @param a a value
 * @param b another value
 * @returns a<b: -1, a=b: 0, a>b: 1
 */
function cmp(a, b) {
    return a < b ? -1 : (a > b ? 1 : 0);
}

/**
 * Gets unique set of values.
 * @param x an iterable
 * @param fn map function (v, i, x)
 */
function uniques(x, fn = null) {
    if (!fn)
        return new Set(x);
    var s = new Set(), i = -1;
    for (var v of x)
        s.add(fn(v, ++i, x));
    return s;
}

function unionMap$(x, y, fn = null) {
    var s = uniques(x, fn);
    var fn = fn || id, i = -1;
    for (var v of y) {
        var v1 = fn(v, ++i, y);
        if (!s.has(v1)) {
            x.push(v);
            s.add(v1);
        }
    }
    return x;
}
function unionDual$(x, y, fc = null, fm = null) {
    var fc = fc || cmp, fm = fm || id;
    var j = -1;
    y: for (var v of y) {
        var v1 = fm(v, ++j, y), i = -1;
        for (var u of x) {
            var u1 = fm(u, ++i, x);
            if (fc(u1, v1) === 0)
                continue y;
        }
        x.push(v);
    }
    return x;
}
/**
 * Gives values present in any array.
 * @param x an array (updated)
 * @param y another array
 * @param fc compare function (a, b)
 * @param fm map function (v, i, x)
 * @returns x
 */
function union$(x, y, fc = null, fm = null) {
    if (fc)
        return unionDual$(x, y, fc, fm);
    else
        return unionMap$(x, y, fm);
}

module.exports = union$;

==> union-update-2.9.5.tgz: package/index.js <==
'use strict';

/**
 * Gives same value.
 * @param v a value
 * @returns v
 */
function id(v) {
    return v;
}

/**
 * Compares two values.
 * @param a a value
 * @param b another value
 * @returns a<b: -1, a=b: 0, a>b: 1
 */
function cmp(a, b) {
    return a < b ? -1 : (a > b ? 1 : 0);
}

/**
 * Gets unique set of values.
 * @param x an iterable
 * @param fn map function (v, i, x)
 */
function uniqueSet(x, fn = null) {
    if (!fn)
        return new Set(x);
    var s = new Set(), i = -1;
    for (var v of x)
        s.add(fn(v, ++i, x));
    return s;
}

function unionMap$(x, y, fn = null) {
    var s = uniqueSet(x, fn);
    var fn = fn || id, i = -1;
    for (var v of y) {
        var v1 = fn(v, ++i, y);
        if (!s.has(v1)) {
            x.push(v);
            s.add(v1);
        }
    }
    return x;
}
function unionDual$(x, y, fc = null, fm = null) {
    var fc = fc || cmp, fm = fm || id;
    var j = -1;
    y: for (var v of y) {
        var v1 = fm(v, ++j, y), i = -1;
        for (var u of x) {
            var u1 = fm(u, ++i, x);
            if (fc(u1, v1) === 0)
                continue y;
        }
        x.push(v);
    }
    return x;
}
/**
 * Gives values present in any array.
 * @param x an array (updated)
 * @param y another array
 * @param fc compare function (a, b)
 * @param fm map function (v, i, x)
 * @returns x
 */
function union$(x, y, fc = null, fm = null) {
    if (fc)
        return unionDual$(x, y, fc, fm);
    else
        return unionMap$(x, y, fm);
}

module.exports = union$;
